==> v1.7.1.zip: mmcv/docs/zh_cn/understand_mmcv/ops.md <==
## 算子

MMCV 提供了检测、分割等任务中常用的算子

| Device                       | CPU | CUDA | MLU | MPS | Ascend |
| ---------------------------- | --- | ---- | --- | --- | ------ |
| ActiveRotatedFilter          | √   | √    |     |     |        |
| AssignScoreWithK             |     | √    |     |     |        |
| BallQuery                    |     | √    |     |     |        |
| BBoxOverlaps                 |     | √    | √   | √   |        |
| BorderAlign                  |     | √    |     |     |        |
| BoxIouRotated                | √   | √    |     |     |        |
| BoxIouQuadri                 | √   | √    |     |     |        |
| CARAFE                       |     | √    | √   |     |        |
| ChamferDistance              |     | √    |     |     |        |
| CrissCrossAttention          |     | √    |     |     |        |
| ContourExpand                | √   |      |     |     |        |
| ConvexIoU                    |     | √    |     |     |        |
| CornerPool                   |     | √    |     |     |        |
| Correlation                  |     | √    |     |     |        |
| Deformable Convolution v1/v2 | √   | √    |     |     |        |
| Deformable RoIPool           |     | √    | √   |     | √      |
| DiffIoURotated               |     | √    |     |     |        |
| DynamicScatter               |     | √    |     |     |        |
| FurthestPointSample          |     | √    |     |     |        |
| FurthestPointSampleWithDist  |     | √    |     |     |        |
| FusedBiasLeakyrelu           |     | √    |     |     | √      |
| GatherPoints                 |     | √    |     |     |        |
| GroupPoints                  |     | √    |     |     |        |
| Iou3d                        |     | √    | √   |     |        |
| KNN                          |     | √    |     |     |        |
| MaskedConv                   |     | √    | √   |     | √      |
| MergeCells                   |     | √    |     |     |        |
| MinAreaPolygon               |     | √    |     |     |        |
| ModulatedDeformConv2d        | √   | √    | √   |     | √      |
| MultiScaleDeformableAttn     |     | √    | √   |     |        |
| NMS                          | √   | √    | √   |     | √      |
| NMSRotated                   | √   | √    |     |     |        |
| NMSQuadri                    | √   | √    |     |     |        |
| PixelGroup                   | √   |      |     |     |        |
| PointsInBoxes                | √   | √    |     |     |        |
| PointsInPolygons             |     | √    |     |     |        |
| PSAMask                      | √   | √    | √   |     |        |
| RotatedFeatureAlign          | √   | √    |     |     |        |
| RoIPointPool3d               |     | √    | √   |     |        |
| RoIPool                      |     | √    | √   |     |        |
| RoIAlignRotated              | √   | √    | √   |     |        |
| RiRoIAlignRotated            |     | √    |     |     |        |
| RoIAlign                     | √   | √    | √   |     |        |
| RoIAwarePool3d               |     | √    | √   |     |        |
| SAConv2d                     |     | √    |     |     |        |
| SigmoidFocalLoss             |     | √    | √   |     | √      |
| SoftmaxFocalLoss             |     | √    |     |     | √      |
| SoftNMS                      |     | √    |     |     |        |
| Sparse Convolution           |     | √    |     |     |        |
| Synchronized BatchNorm       |     | √    |     |     |        |
| ThreeInterpolate             |     | √    |     |     |        |
| ThreeNN                      |     | √    | √   |     |        |
| TINShift                     |     | √    | √   |     |        |
| UpFirDn2d                    |     | √    |     |     |        |
| Voxelization                 | √   | √    |     |     |        |
| PrRoIPool                    |     | √    |     |     |        |

==> v1.7.2.zip: mmcv/docs/zh_cn/understand_mmcv/ops.md <==
## 算子

MMCV 提供了检测、分割等任务中常用的算子

| Device                       | CPU | CUDA | MLU | MPS | Ascend |
| ---------------------------- | --- | ---- | --- | --- | ------ |
| ActiveRotatedFilter          | √   | √    |     |     | √      |
| AssignScoreWithK             |     | √    |     |     |        |
| BallQuery                    |     | √    | √   |     |        |
| BBoxOverlaps                 |     | √    | √   | √   | √      |
| BorderAlign                  |     | √    |     |     |        |
| BoxIouRotated                | √   | √    | √   |     | √      |
| BoxIouQuadri                 | √   | √    |     |     |        |
| CARAFE                       |     | √    | √   |     |        |
| ChamferDistance              |     | √    |     |     |        |
| CrissCrossAttention          |     | √    |     |     |        |
| ContourExpand                | √   |      |     |     |        |
| ConvexIoU                    |     | √    |     |     |        |
| CornerPool                   |     | √    |     |     |        |
| Correlation                  |     | √    |     |     |        |
| Deformable Convolution v1/v2 | √   | √    | √   |     | √      |
| Deformable RoIPool           |     | √    | √   |     | √      |
| DiffIoURotated               |     | √    | √   |     |        |
| DynamicScatter               |     | √    | √   |     |        |
| FurthestPointSample          |     | √    |     |     |        |
| FurthestPointSampleWithDist  |     | √    |     |     |        |
| FusedBiasLeakyrelu           |     | √    |     |     | √      |
| GatherPoints                 |     | √    |     |     | √      |
| GroupPoints                  |     | √    |     |     |        |
| Iou3d                        |     | √    | √   |     |        |
| KNN                          |     | √    |     |     |        |
| MaskedConv                   |     | √    | √   |     | √      |
| MergeCells                   |     | √    |     |     |        |
| MinAreaPolygon               |     | √    |     |     |        |
| ModulatedDeformConv2d        | √   | √    | √   |     | √      |
| MultiScaleDeformableAttn     |     | √    | √   |     |        |
| NMS                          | √   | √    | √   |     | √      |
| NMSRotated                   | √   | √    | √   |     | √      |
| NMSQuadri                    | √   | √    |     |     |        |
| PixelGroup                   | √   |      |     |     |        |
| PointsInBoxes                | √   | √    |     |     |        |
| PointsInPolygons             |     | √    |     |     |        |
| PSAMask                      | √   | √    | √   |     | √      |
| RotatedFeatureAlign          | √   | √    | √   |     |        |
| RoIPointPool3d               |     | √    | √   |     |        |
| RoIPool                      |     | √    | √   |     | √      |
| RoIAlignRotated              | √   | √    | √   |     |        |
| RiRoIAlignRotated            |     | √    |     |     |        |
| RoIAlign                     | √   | √    | √   |     | √      |
| RoIAwarePool3d               |     | √    | √   |     |        |
| SAConv2d                     |     | √    |     |     |        |
| SigmoidFocalLoss             |     | √    | √   |     | √      |
| SoftmaxFocalLoss             |     | √    |     |     | √      |
| SoftNMS                      |     | √    |     |     |        |
| Sparse Convolution           |     | √    | √   |     |        |
| Synchronized BatchNorm       |     | √    |     |     |        |
| ThreeInterpolate             |     | √    |     |     |        |
| ThreeNN                      |     | √    | √   |     |        |
| TINShift                     |     | √    | √   |     |        |
| UpFirDn2d                    |     | √    |     |     |        |
| Voxelization                 | √   | √    | √   |     | √      |
| PrRoIPool                    |     | √    |     |     |        |
